@@ -9,7 +9,7 @@
 #
 package CatalystX::Controller::ExtJS::Direct::API;
 BEGIN {
-  $CatalystX::Controller::ExtJS::Direct::API::VERSION = '1.122000';
+  $CatalystX::Controller::ExtJS::Direct::API::VERSION = '1.123000';
 }
 # ABSTRACT: API and router controller for Ext.Direct
 use Moose;
@@ -55,7 +55,8 @@ sub _build_api {
     my $data   = {};
     foreach my $name ( $c->controllers ) {
         my $controller = $c->controller($name);
-        $name =~ s/:://;
+        $name =~ s/^API:://;
+        $name =~ s/:://g;
         my $meta       = $controller->meta;
         next
           unless ( $controller->can('is_direct') || $meta->does_role('CatalystX::Controller::ExtJS::Direct') );
@@ -119,7 +120,7 @@ sub router {
             && exists $routes->{ $req->{action} }
             && exists $routes->{ $req->{action} }->{ $req->{method} } )
         {
-            $self->status_bad_request( $c, { message => 'method not found' } );
+            $self->status_bad_request( $c, { message => sprintf('method %s in action %s does not exist', $req->{method}, $req->{action}) } );
             return;
         }
          my $route = $routes->{ $req->{action} }->{ $req->{method} };
@@ -198,7 +199,7 @@ CatalystX::Controller::ExtJS::Direct::API - API and router controller for Ext.Di
 
 =head1 VERSION
 
-version 1.122000
+version 1.123000
 
 =head1 ACTIONS
 
